Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitaly.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to '_support')
-rw-r--r--_support/makegen.go18
1 files changed, 9 insertions, 9 deletions
diff --git a/_support/makegen.go b/_support/makegen.go
index 2a6a83380..3bd410f81 100644
--- a/_support/makegen.go
+++ b/_support/makegen.go
@@ -74,7 +74,7 @@ func (gm *gitalyMake) GoImports() string { return "bin/goimports" }
func (gm *gitalyMake) GoCovMerge() string { return "bin/gocovmerge" }
func (gm *gitalyMake) GoLint() string { return "bin/golint" }
func (gm *gitalyMake) GoVendor() string { return "bin/govendor" }
-func (gm *gitalyMake) MegaCheck() string { return "bin/megacheck" }
+func (gm *gitalyMake) StaticCheck() string { return filepath.Join(gm.BuildDir(), "bin/staticcheck") }
func (gm *gitalyMake) CoverageDir() string { return filepath.Join(gm.BuildDir(), "cover") }
func (gm *gitalyMake) GitalyRubyDir() string { return filepath.Join(gm.SourceDir(), "ruby") }
func (gm *gitalyMake) GitlabShellRelDir() string { return "ruby/vendor/gitlab-shell" }
@@ -325,7 +325,7 @@ rspec: assemble-go prepare-tests
cd {{ .GitalyRubyDir }} && bundle exec rspec
.PHONY: verify
-verify: lint check-formatting megacheck govendor-status notice-up-to-date govendor-tagged rubocop
+verify: lint check-formatting staticcheck govendor-status notice-up-to-date govendor-tagged rubocop
.PHONY: lint
lint: {{ .GoLint }}
@@ -349,14 +349,14 @@ format: {{ .GoImports }}
# so it can be used as a replacement.
@cd {{ .SourceDir }} && goimports -w -l {{ join .GoFiles " " }}
-.PHONY: megacheck
-megacheck: {{ .MegaCheck }}
- # megacheck
- @{{ .MegaCheck }} {{ join .AllPackages " " }}
+.PHONY: staticcheck
+staticcheck: {{ .StaticCheck }}
+ # staticcheck
+ @cd {{ .SourceDir }} && {{ .StaticCheck }} {{ join .AllPackages " " }}
-# Install megacheck
-{{ .MegaCheck }}:
- go get honnef.co/go/tools/cmd/megacheck
+# Install staticcheck
+{{ .StaticCheck }}:
+ go get honnef.co/go/tools/cmd/staticcheck
.PHONY: govendor-status
govendor-status: {{ .GoVendor }}